@@ -54,8 +54,8 @@ sub new {
 	{#State 0
 		DEFAULT => -3,
 		GOTOS => {
-			'input' => 1,
-			'declarations' => 2
+			'declarations' => 2,
+			'input' => 1
 		}
 	},
 	{#State 1
@@ -65,166 +65,166 @@ sub new {
 	},
 	{#State 2
 		ACTIONS => {
-			'PERCENT_FILE_PREFIX' => 4,
-			'PERCENT_PARSE_PARAM' => 5,
-			'PERCENT_YACC' => 6,
-			'PERCENT_OUTPUT' => 8,
-			'PERCENT_DEFINES' => 9,
-			'PERCENT_LEFT' => 11,
-			'PERCENT_VERBOSE' => 12,
-			'PERCENT_DEBUG' => 13,
-			'PERCENT_PURE_PARSER' => 14,
-			'PERCENT_TOKEN_TABLE' => 17,
-			'SEMICOLON' => 16,
-			'PERCENT_TOKEN' => 15,
-			'PERCENT_TYPE' => 19,
-			'PERCENT_START' => 21,
-			"%%" => 22,
-			'PERCENT_LOCATIONS' => 23,
-			'PERCENT_UNION' => 24,
-			'PERCENT_NO_LINES' => 25,
+			'PERCENT_DEFINES' => 19,
+			'PERCENT_START' => 17,
+			'PERCENT_RIGHT' => 18,
+			'PERCENT_YACC' => 15,
+			'PERCENT_TOKEN' => 14,
+			'PERCENT_TYPE' => 28,
+			'PERCENT_PURE_PARSER' => 27,
 			'PERCENT_EXPECT' => 26,
-			'PERCENT_NAME_PREFIX' => 29,
-			'PROLOGUE' => 28,
-			'PERCENT_NONASSOC' => 30,
-			'PERCENT_RIGHT' => 31
+			'PERCENT_LEFT' => 29,
+			"%%" => 30,
+			'PERCENT_UNION' => 22,
+			'PERCENT_OUTPUT' => 23,
+			'PERCENT_DEBUG' => 21,
+			'PERCENT_NO_LINES' => 25,
+			'PERCENT_NONASSOC' => 24,
+			'PERCENT_LOCATIONS' => 4,
+			'PERCENT_TOKEN_TABLE' => 7,
+			'PERCENT_VERBOSE' => 13,
+			'PERCENT_NAME_PREFIX' => 9,
+			'PERCENT_FILE_PREFIX' => 8,
+			'PERCENT_PARSE_PARAM' => 12,
+			'SEMICOLON' => 11,
+			'PROLOGUE' => 10
 		},
 		GOTOS => {
-			'precedence_declaration' => 7,
-			'grammar_declaration' => 27,
-			'symbol_declaration' => 18,
-			'declaration' => 10,
-			'precedence_declarator' => 20
+			'symbol_declaration' => 5,
+			'precedence_declarator' => 20,
+			'grammar_declaration' => 31,
+			'declaration' => 6,
+			'precedence_declaration' => 16
 		}
 	},
 	{#State 3
 		DEFAULT => 0
 	},
 	{#State 4
+		DEFAULT => -11
+	},
+	{#State 5
+		DEFAULT => -22
+	},
+	{#State 6
+		DEFAULT => -4
+	},
+	{#State 7
+		DEFAULT => -17
+	},
+	{#State 8
 		ACTIONS => {
 			'EQUAL' => 32
 		}
 	},
-	{#State 5
-		DEFAULT => -15
-	},
-	{#State 6
-		DEFAULT => -19
-	},
-	{#State 7
-		DEFAULT => -21
-	},
-	{#State 8
-		DEFAULT => -14
-	},
 	{#State 9
-		DEFAULT => -8
+		ACTIONS => {
+			'EQUAL' => 33
+		}
 	},
 	{#State 10
-		DEFAULT => -4
+		DEFAULT => -6
 	},
 	{#State 11
-		DEFAULT => -29
-	},
-	{#State 12
-		DEFAULT => -18
-	},
-	{#State 13
-		DEFAULT => -7
-	},
-	{#State 14
-		DEFAULT => -16
-	},
-	{#State 15
-		ACTIONS => {
-			'TYPE' => 36,
-			'IDENT' => 35
-		},
-		GOTOS => {
-			'ID' => 33,
-			'symbol_def' => 34,
-			'symbol_defs_1' => 37
-		}
-	},
-	{#State 16
 		DEFAULT => -20
 	},
+	{#State 12
+		DEFAULT => -15
+	},
+	{#State 13
+		DEFAULT => -18
+	},
+	{#State 14
+		ACTIONS => {
+			'IDENT' => 36,
+			'TYPE' => 37
+		},
+		GOTOS => {
+			'symbol_defs_1' => 34,
+			'symbol_def' => 35,
+			'ID' => 38
+		}
+	},
+	{#State 15
+		DEFAULT => -19
+	},
+	{#State 16
+		DEFAULT => -21
+	},
 	{#State 17
-		DEFAULT => -17
+		ACTIONS => {
+			'STRING' => 42,
+			'IDENT' => 36
+		},
+		GOTOS => {
+			'symbol' => 40,
+			'ID' => 39,
+			'string_as_id' => 41
+		}
 	},
 	{#State 18
-		DEFAULT => -22
+		DEFAULT => -30
 	},
 	{#State 19
-		ACTIONS => {
-			'TYPE' => 38
-		}
+		DEFAULT => -8
 	},
 	{#State 20
 		ACTIONS => {
-			'TYPE' => 40
+			'TYPE' => 44
 		},
 		DEFAULT => -32,
 		GOTOS => {
-			'type_opt' => 39
+			'type_opt' => 43
 		}
 	},
 	{#State 21
-		ACTIONS => {
-			'IDENT' => 35,
-			'STRING' => 42
-		},
-		GOTOS => {
-			'ID' => 41,
-			'symbol' => 44,
-			'string_as_id' => 43
-		}
+		DEFAULT => -7
 	},
 	{#State 22
 		ACTIONS => {
-			'ERROR' => 46,
-			'ID_COLON' => 48,
-			'SEMICOLON' => 47
-		},
-		DEFAULT => -2,
-		GOTOS => {
-			'grammar' => 49,
-			'rules_or_grammar_declaration' => 50,
-			'rules' => 45
+			'BRACED_CODE' => 45
 		}
 	},
 	{#State 23
-		DEFAULT => -11
+		DEFAULT => -14
 	},
 	{#State 24
-		ACTIONS => {
-			'BRACED_CODE' => 51
-		}
+		DEFAULT => -31
 	},
 	{#State 25
 		DEFAULT => -13
 	},
 	{#State 26
 		ACTIONS => {
-			'INT' => 52
+			'INT' => 46
 		}
 	},
 	{#State 27
-		DEFAULT => -5
+		DEFAULT => -16
 	},
 	{#State 28
-		DEFAULT => -6
-	},
-	{#State 29
 		ACTIONS => {
-			'EQUAL' => 53
+			'TYPE' => 47
 		}
 	},
+	{#State 29
+		DEFAULT => -29
+	},
 	{#State 30
-		DEFAULT => -31
+		ACTIONS => {
+			'ID_COLON' => 51,
+			'ERROR' => 49,
+			'SEMICOLON' => 53
+		},
+		DEFAULT => -2,
+		GOTOS => {
+			'rules' => 52,
+			'grammar' => 50,
+			'rules_or_grammar_declaration' => 48
+		}
 	},
 	{#State 31
-		DEFAULT => -30
+		DEFAULT => -5
 	},
 	{#State 32
 		ACTIONS => {
@@ -236,134 +236,134 @@ sub new {
 	},
 	{#State 33
 		ACTIONS => {
-			'STRING' => 42,
-			'INT' => 57
+			'STRING' => 54
 		},
-		DEFAULT => -36,
 		GOTOS => {
-			'string_as_id' => 56
+			'string_content' => 56
 		}
 	},
 	{#State 34
-		DEFAULT => -40
-	},
-	{#State 35
-		DEFAULT => -64
-	},
-	{#State 36
 		ACTIONS => {
-			'IDENT' => 35
-		},
-		GOTOS => {
-			'ID' => 33,
-			'symbol_def' => 34,
-			'symbol_defs_1' => 58
-		}
-	},
-	{#State 37
-		ACTIONS => {
-			'IDENT' => 35
+			'IDENT' => 36
 		},
 		DEFAULT => -25,
 		GOTOS => {
-			'ID' => 33,
-			'symbol_def' => 59
+			'ID' => 38,
+			'symbol_def' => 57
+		}
+	},
+	{#State 35
+		DEFAULT => -40
+	},
+	{#State 36
+		DEFAULT => -64
+	},
+	{#State 37
+		ACTIONS => {
+			'IDENT' => 36
+		},
+		GOTOS => {
+			'symbol_def' => 35,
+			'symbol_defs_1' => 58,
+			'ID' => 38
 		}
 	},
 	{#State 38
 		ACTIONS => {
-			'IDENT' => 35,
-			'STRING' => 42
+			'STRING' => 42,
+			'INT' => 59
 		},
+		DEFAULT => -36,
 		GOTOS => {
-			'ID' => 41,
-			'symbols_1' => 61,
-			'symbol' => 60,
-			'string_as_id' => 43
+			'string_as_id' => 60
 		}
 	},
 	{#State 39
-		ACTIONS => {
-			'IDENT' => 35,
-			'STRING' => 42
-		},
-		GOTOS => {
-			'ID' => 41,
-			'symbols_1' => 62,
-			'symbol' => 60,
-			'string_as_id' => 43
-		}
+		DEFAULT => -55
 	},
 	{#State 40
-		DEFAULT => -33
+		DEFAULT => -23
 	},
 	{#State 41
-		DEFAULT => -55
+		DEFAULT => -56
 	},
 	{#State 42
 		DEFAULT => -60
 	},
 	{#State 43
-		DEFAULT => -56
+		ACTIONS => {
+			'STRING' => 42,
+			'IDENT' => 36
+		},
+		GOTOS => {
+			'string_as_id' => 41,
+			'symbols_1' => 61,
+			'ID' => 39,
+			'symbol' => 62
+		}
 	},
 	{#State 44
-		DEFAULT => -23
+		DEFAULT => -33
 	},
 	{#State 45
-		DEFAULT => -44
+		DEFAULT => -24
 	},
 	{#State 46
+		DEFAULT => -9
+	},
+	{#State 47
 		ACTIONS => {
-			'IDENT' => 35,
-			'SEMICOLON' => 63,
+			'IDENT' => 36,
 			'STRING' => 42
 		},
 		GOTOS => {
-			'ID' => 41,
-			'symbol' => 64,
-			'string_as_id' => 43
+			'symbols_1' => 63,
+			'string_as_id' => 41,
+			'symbol' => 62,
+			'ID' => 39
 		}
 	},
-	{#State 47
-		DEFAULT => -47
-	},
 	{#State 48
-		DEFAULT => -51,
-		GOTOS => {
-			'rhses_1' => 66,
-			'rhs' => 65
-		}
+		DEFAULT => -42
 	},
 	{#State 49
 		ACTIONS => {
-			'ERROR' => 46,
-			'ID_COLON' => 48,
-			"%%" => 67,
-			'SEMICOLON' => 47
+			'SEMICOLON' => 65,
+			'IDENT' => 36,
+			'STRING' => 42
 		},
-		DEFAULT => -62,
 		GOTOS => {
-			'rules_or_grammar_declaration' => 69,
-			'rules' => 45,
-			'epilogue_opt' => 68
+			'symbol' => 64,
+			'ID' => 39,
+			'string_as_id' => 41
 		}
 	},
 	{#State 50
-		DEFAULT => -42
+		ACTIONS => {
+			'ERROR' => 49,
+			'ID_COLON' => 51,
+			"%%" => 67,
+			'SEMICOLON' => 53
+		},
+		DEFAULT => -62,
+		GOTOS => {
+			'epilogue_opt' => 66,
+			'rules_or_grammar_declaration' => 68,
+			'rules' => 52
+		}
 	},
 	{#State 51
-		DEFAULT => -24
+		DEFAULT => -51,
+		GOTOS => {
+			'rhs' => 69,
+			'rhses_1' => 70
+		}
 	},
 	{#State 52
-		DEFAULT => -9
+		DEFAULT => -44
 	},
 	{#State 53
-		ACTIONS => {
-			'STRING' => 54
-		},
-		GOTOS => {
-			'string_content' => 70
-		}
+		DEFAULT => -47
 	},
 	{#State 54
 		DEFAULT => -61
@@ -372,9 +372,22 @@ sub new {
 		DEFAULT => -10
 	},
 	{#State 56
-		DEFAULT => -38
+		DEFAULT => -12
 	},
 	{#State 57
+		DEFAULT => -41
+	},
+	{#State 58
+		ACTIONS => {
+			'IDENT' => 36
+		},
+		DEFAULT => -26,
+		GOTOS => {
+			'symbol_def' => 57,
+			'ID' => 38
+		}
+	},
+	{#State 59
 		ACTIONS => {
 			'STRING' => 42
 		},
@@ -383,48 +396,35 @@ sub new {
 			'string_as_id' => 71
 		}
 	},
-	{#State 58
-		ACTIONS => {
-			'IDENT' => 35
-		},
-		DEFAULT => -26,
-		GOTOS => {
-			'ID' => 33,
-			'symbol_def' => 59
-		}
-	},
-	{#State 59
-		DEFAULT => -41
-	},
 	{#State 60
-		DEFAULT => -34
+		DEFAULT => -38
 	},
 	{#State 61
 		ACTIONS => {
-			'IDENT' => 35,
-			'STRING' => 42
-		},
-		DEFAULT => -27,
-		GOTOS => {
-			'ID' => 41,
-			'symbol' => 72,
-			'string_as_id' => 43
-		}
-	},
-	{#State 62
-		ACTIONS => {
-			'IDENT' => 35,
+			'IDENT' => 36,
 			'STRING' => 42
 		},
 		DEFAULT => -28,
 		GOTOS => {
-			'ID' => 41,
 			'symbol' => 72,
-			'string_as_id' => 43
+			'ID' => 39,
+			'string_as_id' => 41
 		}
 	},
+	{#State 62
+		DEFAULT => -34
+	},
 	{#State 63
-		DEFAULT => -46
+		ACTIONS => {
+			'STRING' => 42,
+			'IDENT' => 36
+		},
+		DEFAULT => -27,
+		GOTOS => {
+			'symbol' => 72,
+			'ID' => 39,
+			'string_as_id' => 41
+		}
 	},
 	{#State 64
 		ACTIONS => {
@@ -432,40 +432,40 @@ sub new {
 		}
 	},
 	{#State 65
-		ACTIONS => {
-			'IDENT' => 35,
-			'BRACED_CODE' => -57,
-			'PERCENT_PREC' => 75,
-			'STRING' => 42,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77
-		},
-		DEFAULT => -49,
-		GOTOS => {
-			'ID' => 41,
-			'symbol' => 76,
-			'action_opt' => 74,
-			'string_as_id' => 43
-		}
+		DEFAULT => -46
 	},
 	{#State 66
-		ACTIONS => {
-			'PIPE' => 78
-		},
-		DEFAULT => -48
+		DEFAULT => -1
 	},
 	{#State 67
 		ACTIONS => {
-			'EPILOGUE' => 79
+			'EPILOGUE' => 74
 		}
 	},
 	{#State 68
-		DEFAULT => -1
-	},
-	{#State 69
 		DEFAULT => -43
 	},
+	{#State 69
+		ACTIONS => {
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 76,
+			'BRACED_CODE' => -57,
+			'IDENT' => 36,
+			'STRING' => 42,
+			'PERCENT_PREC' => 77
+		},
+		DEFAULT => -49,
+		GOTOS => {
+			'string_as_id' => 41,
+			'action_opt' => 75,
+			'symbol' => 78,
+			'ID' => 39
+		}
+	},
 	{#State 70
-		DEFAULT => -12
+		ACTIONS => {
+			'PIPE' => 79
+		},
+		DEFAULT => -48
 	},
 	{#State 71
 		DEFAULT => -39
@@ -477,62 +477,62 @@ sub new {
 		DEFAULT => -45
 	},
 	{#State 74
-		ACTIONS => {
-			'BRACED_CODE' => 80
-		},
-		GOTOS => {
-			'action' => 81
-		}
+		DEFAULT => -63
 	},
 	{#State 75
 		ACTIONS => {
-			'IDENT' => 35,
-			'STRING' => 42
+			'BRACED_CODE' => 81
 		},
 		GOTOS => {
-			'ID' => 41,
-			'symbol' => 82,
-			'string_as_id' => 43
+			'action' => 80
 		}
 	},
 	{#State 76
-		DEFAULT => -52
-	},
-	{#State 77
 		DEFAULT => -58
 	},
+	{#State 77
+		ACTIONS => {
+			'IDENT' => 36,
+			'STRING' => 42
+		},
+		GOTOS => {
+			'ID' => 39,
+			'symbol' => 82,
+			'string_as_id' => 41
+		}
+	},
 	{#State 78
+		DEFAULT => -52
+	},
+	{#State 79
 		DEFAULT => -51,
 		GOTOS => {
 			'rhs' => 83
 		}
 	},
-	{#State 79
-		DEFAULT => -63
-	},
 	{#State 80
-		DEFAULT => -59
+		DEFAULT => -53
 	},
 	{#State 81
-		DEFAULT => -53
+		DEFAULT => -59
 	},
 	{#State 82
 		DEFAULT => -54
 	},
 	{#State 83
 		ACTIONS => {
-			'IDENT' => 35,
+			'PERCENT_PREC' => 77,
 			'BRACED_CODE' => -57,
-			'PERCENT_PREC' => 75,
-			'STRING' => 42,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 76,
+			'IDENT' => 36,
+			'STRING' => 42
 		},
 		DEFAULT => -50,
 		GOTOS => {
-			'ID' => 41,
-			'symbol' => 76,
-			'action_opt' => 74,
-			'string_as_id' => 43
+			'ID' => 39,
+			'symbol' => 78,
+			'string_as_id' => 41,
+			'action_opt' => 75
 		}
 	}
 ],
